@@ -23,6 +23,6 @@ Puppet::Type.newtype(:keystone_role) do
 
   # we should not do anything until the keystone service is started
   autorequire(:anchor) do
-    ['keystone_started']
+    ['keystone::service::end']
   end
 end
