@@ -2,6 +2,10 @@ require 'spec_helper'
 
 describe 'keystone::client' do
 
+  let :facts do
+    @default_facts.merge({ :osfamily => 'Debian' })
+  end
+
   describe "with default parameters" do
     it { is_expected.to contain_package('python-keystoneclient').with(
         'ensure' => 'present',
