@@ -17,8 +17,7 @@ describe 'keystone::logging' do
       :publish_errors => true,
       :default_log_levels => {
         'amqp' => 'WARN', 'amqplib' => 'WARN', 'boto' => 'WARN',
-        'qpid' => 'WARN', 'sqlalchemy' => 'WARN', 'suds' => 'INFO',
-        'iso8601' => 'WARN',
+        'sqlalchemy' => 'WARN', 'suds' => 'INFO', 'iso8601' => 'WARN',
         'requests.packages.urllib3.connectionpool' => 'WARN' },
      :fatal_deprecations => true,
      :instance_format => '[instance: %(uuid)s] ',
@@ -29,7 +28,6 @@ describe 'keystone::logging' do
      :log_facility => 'LOG_FOO',
      :log_dir => '/var/log',
      :log_file => '/var/tmp/keystone_random.log',
-     :verbose => true,
      :debug => true,
     }
   end
@@ -40,7 +38,6 @@ describe 'keystone::logging' do
       is_expected.to contain_keystone_config('DEFAULT/use_stderr').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_keystone_config('DEFAULT/log_dir').with(:value => '/var/log/keystone')
       is_expected.to contain_keystone_config('DEFAULT/log_file').with(:value => '<SERVICE DEFAULT>')
-      is_expected.to contain_keystone_config('DEFAULT/verbose').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_keystone_config('DEFAULT/debug').with(:value => '<SERVICE DEFAULT>')
     end
   end
@@ -52,7 +49,6 @@ describe 'keystone::logging' do
       is_expected.to contain_keystone_config('DEFAULT/syslog_log_facility').with(:value => 'LOG_FOO')
       is_expected.to contain_keystone_config('DEFAULT/log_dir').with(:value => '/var/log')
       is_expected.to contain_keystone_config('DEFAULT/log_file').with(:value => '/var/tmp/keystone_random.log')
-      is_expected.to contain_keystone_config('DEFAULT/verbose').with(:value => 'true')
       is_expected.to contain_keystone_config('DEFAULT/debug').with(:value => 'true')
     end
   end
@@ -99,7 +95,7 @@ describe 'keystone::logging' do
         true)
 
       is_expected.to contain_keystone_config('DEFAULT/default_log_levels').with_value(
-        'amqp=WARN,amqplib=WARN,boto=WARN,iso8601=WARN,qpid=WARN,requests.packages.urllib3.connectionpool=WARN,sqlalchemy=WARN,suds=INFO')
+        'amqp=WARN,amqplib=WARN,boto=WARN,iso8601=WARN,requests.packages.urllib3.connectionpool=WARN,sqlalchemy=WARN,suds=INFO')
 
       is_expected.to contain_keystone_config('DEFAULT/fatal_deprecations').with_value(
         true)
