@@ -109,7 +109,7 @@ id="newid"
       klass.expects(:request_timeout).returns(0)
       klass.expects(:openstack)
         .with('project', 'show', '--format', 'shell', ['no_project', '--domain', 'Default'])
-        .times(2)
+        .once
         .raises(Puppet::ExecutionFailure, "Execution of '/usr/bin/openstack project show --format shell no_project' returned 1: No project with a name or ID of 'no_project' exists.")
       expect(klass.fetch_project('no_project', 'Default')).to be_falsey
     end
@@ -141,7 +141,7 @@ id="the_project_id"
       klass.expects(:request_timeout).returns(0)
       klass.expects(:openstack)
         .with('user', 'show', '--format', 'shell', ['no_user', '--domain', 'Default'])
-        .times(2)
+        .once
         .raises(Puppet::ExecutionFailure, "Execution of '/usr/bin/openstack user show --format shell no_user' returned 1: No user with a name or ID of 'no_user' exists.")
       expect(klass.fetch_user('no_user', 'Default')).to be_falsey
     end
